@@ -1,9 +1,10 @@
-#!/bin/sh
+#!/bin/bash
 #
 # Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
 #     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-#     2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014
-#     Massachusetts Institute of Technology
+#     2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
+#     2015, 2016, 2017, 2018, 2019 Massachusetts Institute of
+#     Technology
 #
 # This file is part of MIT/GNU Scheme.
 #
@@ -25,5 +26,13 @@
 # Utility to make TAGS file for the MIT/GNU Scheme compiler directory.
 # The working directory must be the compiler directory.
 
-etags back/*.scm base/*.scm fggen/*.scm fgopt/*.scm machine/*.scm \
-      rtlbase/*.scm rtlgen/*.scm rtlopt/*.scm
+set -e
+
+if [[ -d machine ]]; then
+    MACHINES=(machine/*.scm machine/*.pkg)
+else
+    MACHINES=(machines/*/*.scm machines/*/*.pkg)
+fi
+
+etags back/*.scm base/*.scm fggen/*.scm fgopt/*.scm \
+      rtlbase/*.scm rtlgen/*.scm rtlopt/*.scm "${MACHINES[@]}"
